@@ -165,7 +165,9 @@ class Blackwhite(db.Model):
     range = db.Column(db.Integer, nullable=False, info='范围 0 内网(MAC) 1 外网(IP或域名) ')
     text = db.Column(db.String(200, 'utf8mb4_0900_ai_ci'), nullable=False, server_default=db.FetchedValue())
     store_id = db.Column(db.Integer, nullable=False, index=True, server_default=db.FetchedValue(), info='场所id')
-
+    source = db.Column(db.Integer, index=True, server_default=db.FetchedValue(), info='0 手动 1 自动 21 接口（任子行） 22 接口（百卓）')
+    device_id = db.Column(db.Integer, index=True, server_default=db.FetchedValue(), info='绑定到设备的id号 0 没有绑定到设备')
+    label = db.Column(db.String(200), info='标签')
 
 
 class Branch(db.Model):
@@ -521,19 +523,6 @@ class StoreExt(db.Model):
 
 
 
-class Whitelist(db.Model):
-    __tablename__ = 'whitelist'
-
-    id = db.Column(db.Integer, primary_key=True)
-    created_at = db.Column(db.DateTime, nullable=False, server_default=db.FetchedValue())
-    updated_at = db.Column(db.DateTime, nullable=False, server_default=db.FetchedValue())
-    mac = db.Column(db.String(17, 'utf8mb4_general_ci'), nullable=False, index=True, info='mac地址')
-    store_id = db.Column(db.Integer, nullable=False, index=True, server_default=db.FetchedValue(), info='场所ID号')
-    device_id = db.Column(db.Integer, nullable=False, index=True, info='设备ID号')
-    source = db.Column(db.Integer, nullable=False, index=True, info='0 手动 1 自动 21 任子行 22 百卓')
-
-
-
 class WhitelistPrefix(db.Model):
     __tablename__ = 'whitelist_prefix'
 
